﻿Type=Class
Version=5.51
ModulesStructureVersion=1
B4J=true
@EndOfDesignText@
' Class module
' Name: ConfigForm
' Purpose: Manage settings. Stored in rocodesnip.ini
' Notes:
' Ensure all ini keys are in lowercase!
' TODO: None
'
Private Sub Class_Globals
	Private fx As JFX
	Private frm As Form
	'
	Public	Result As Boolean
	' Buttons
	Private btnOK As Button
	Private btnCancel As Button
	' Settings
	Private chkCopyItemWithSubName As CheckBox
	Private chkViewItemWebView As CheckBox
	Private chkCodeWrapText As CheckBox
	Private chkReuseListViewIndex As CheckBox
	Private chkStayOnTop As CheckBox
	Private txtDependencies As TextArea
	Private btnDependenciesSort As Button
	Private btnDependenciesB4JLibrary As Button
	Private btnDependenciesAddLibrary As Button
	Private txtDateTimeFormat As TextField
	Private btnDateTimeFormatHint As Button
	Private lblFavoriteItem As Label
	Private btnClearFavoriteItem As Button
End Sub

'Initializes the object. You can add parameters to this method if needed.
Public Sub Initialize
	Main.AppLog("ConfigForm Init :: Start")
	' Init the form and give the form a title and make it a utility form (toolbox type of form)
	frm.Initialize("frm", 500, 500)
	frm.Title = "Configuration"
	frm.Resizable = False
	frm.SetFormStyle("UTILITY")
	frm.RootPane.LoadLayout("ConfigForm")
	Main.AppLog("ConfigForm Init :: End")
End Sub

' Show the ItemForm (toolbox Type)
Public Sub Show
	Main.AppLog("ConfigForm Show :: Start")			
	' Read Ini Entries
	lblFavoriteItem.Text 			= Main.gmapIni.getKey("favoriteitem", "Not Defined")
	chkCopyItemWithSubName.Checked	= (Main.gmapIni.getKey("copyitemwithsubname", False) = True)
	chkViewItemWebView.Checked		= (Main.gmapIni.getKey("viewitemwebview", False) = True)
	chkCodeWrapText.Checked			= (Main.gmapIni.getKey("codewraptext", False) = True)
	chkReuseListViewIndex.Checked	= (Main.gmapIni.getKey("reuselistviewindex", False) = True)
	chkStayOnTop.Checked			= (Main.gmapIni.getKey("stayontop", False) = True)
	txtDependencies.Text			= Main.gmapIni.getKey("dependencies", "")
	txtDateTimeFormat.Text			= Main.gmapIni.getKey("datetimeformat", "dd.MM.yyyy")
	' Show the form and wait till closed via button OK or CANCEL
	frm.ShowAndWait						
	Main.AppLog("ConfigForm Show :: End")			
End Sub

' Save settings to ini file and close
Private Sub btnOK_Action
	Main.AppLog("btnOK :: Start")			
	' Update Ini Entries
	Main.gmapIni.putKey("copyitemwithsubname", chkCopyItemWithSubName.Checked)
	Main.gmapIni.putKey("viewitemwebview", chkViewItemWebView.Checked)
	Main.gmapIni.putKey("codewraptext", chkCodeWrapText.Checked)
	Main.gmapIni.putKey("reuselistviewindex", chkReuseListViewIndex.Checked)
	Main.gmapIni.putKey("stayontop", chkStayOnTop.Checked)
	Main.gmapIni.putKey("dependencies", txtDependencies.Text)
	If txtDateTimeFormat.Text.Length = 0 Then txtDateTimeFormat.Text = "dd.MM.YYYY HH:mm"
	Main.gmapIni.putKey("datetimeformat", txtDateTimeFormat.Text)
	' Set global boolean result to true
	Result = True
	frm.Close	
	Main.AppLog("btnOK :: End")			
End Sub

Private Sub btnCancel_Action
	' Set global boolean result to false
	Result = False
	frm.Close	
End Sub

' Sort the content of the field dependencies (textarea)
Private Sub btnDependenciesSort_Action
	txtDependencies.Text = sortMultiLineString(txtDependencies.Text)
End Sub

' Get list of library files from the b4j library folder or the additional library folder
' Selected are only the XML files from the related JAR files as these are documented
' Parameter: libtype is "b4jlibrary" or "addlibrary"
' Returns: List if libraries seperated by CRLF
Private Sub getLibraryFiles(libtype As String) As String
	Dim libs As String = ""
	Dim dc As DirectoryChooser	
	dc.Initialize
	If File.IsDirectory(Main.gmapIni.getKey(libtype, ""), "") Then dc.InitialDirectory = Main.gmapIni.getKey(libtype, "")
	dc.Title = "Get Library Folder"
	Dim folder As String
	folder = dc.Show(frm)
	If folder.Length > 0 Then
		Main.gmapIni.putKey(libtype, folder)
		Dim l As List
		l.Initialize
		l = File.ListFiles(folder)	
		Main.AppLog("Folder: " & folder & " - Files: " & l.Size)
		If l.Size > 0 Then
			Dim s As String
			For i = 0 To l.Size - 1
				s = l.get(i) 
				If s.ToLowerCase.Contains(".xml") Then 
					libs = libs & s.SubString2(0, s.LastIndexOf(".")) & CRLF
				End If
			Next
		End If
	End If
	Return libs
End Sub

Private Sub btnDependenciesB4JLibrary_Action
	txtDependencies.Text = txtDependencies.Text & getLibraryFiles("b4jlibrary")
End Sub

Private Sub btnDependenciesAddLibrary_Action
	txtDependencies.Text = txtDependencies.Text & getLibraryFiles("addlibrary")
End Sub

' Sort a multiline string ascending. The lines are seperated by CRLF
' Parameter: String to Sort
' Returns String ASC 
Private Sub sortMultiLineString(mls As String) As String
	If mls.Length = 0 Then Return ""
	' Split the text
	Dim s() As String = Regex.Split(CRLF, mls)
	Dim l As List
	l.Initialize
	l.AddAll(s)
	l.sort(True)
	mls = ""
	For i = 0 To s.Length - 1
  		mls = mls & l.get(i) & CRLF
	Next
	Return mls
End Sub

' Show hint window showing some date time format examples
Private Sub btnDateTimeFormatHint_Action
	Dim strTitle As String ="Date Time Format Hints"
	Dim strMsg As String
	strMsg = "<H1>Date Format Examples</H1><HR>" & _ 
			"<P>dd.MM.yyyy HH:mm = 04.05.2014 09:33</P>" & _
			"<P>dd.MM.yyyy = 04.05.2014</P>" & _ 
			"<P>yyyyMMdd = 20140504</P>" & _ 
			"<P>MM/dd/yy = 05/04/14</P>" & _ 
			"<P>dd/MM/yy = 04/05/14</P>" & _ 
			"<P>dd-MMM-yy = 04-Mai-14</P>" & _ 
			"<P>yyyy.MM.dd.HH.mm.ss = 2014.05.04.09.33.01</P>" & _ 
			"<P>E, dd MMM yyyy HH:mm:ss Z = So, 04 Mai 2014 09:33:01 +0200</P>" & _ 
			"<P>EEEE, dd MMMM yyyy HH:mm:ss zzzz = Sontag, 04 Mai 2014 09:33:01 Mitteleuropäische Sommerzeit</P>"
	'	
	Main.gDlg.MessageHTMLDialog(strTitle, strMsg)	
End Sub

' Clear the favorite item entry
Sub btnClearFavoriteItem_Action
	lblFavoriteItem.Text = "Not Defined"
	Main.gmapIni.putKey("favoriteitem", "")
End Sub
